calendar 1979
allocate 2060:1
open data "input_Labour force 1978_79 to 2012_13.xls"
data(format=xls,org=rows,noverbose) 1979:1 2013:1
SOURCE(NOECHO) "HPFILTER.SRC"

/*
Disp 'The symbols /* and */ bracketing any expression prevent RATS from operating on the code
*/

* This uses the Burniaux method (OECD) for dynamic cohort analysis BUT INCLUDES TRENDS IN EXIT OR ENTRY RATES

compute malep = 0.99
compute femalep = 0.99


DECLARE LABEL AGE SEX
DECLARE INTEGER AGES
DECLARE LABEL PART
DECLARE INTEGER TIME
declare integer k
DECLARE LABEL PCHANGE
set trend = t
DECLARE LABEL POSEXIT POSENT



DOFOR AGE = '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569' '70'
  DOFOR SEX = 'M' 'F'
     SET(SCRATCH) %S('PR'+SEX+AGE) = %S('PR'+SEX+AGE)/100.0
     @HPFILTER(LAMBDA=100)  %S('PR'+SEX+AGE)  1979:1  2013:1  %S('HPPR'+SEX+AGE)
end dofor sex
end dofor AGE

*print 1979:1 2013:1 HPPRF1519
* ULTIMATELY PROJECTIONS ARE GOING INTO A FORMAT OF %S('P'+SEX+AGE)  SO CREATE THESE NOW
DOFOR AGE = '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569' '70'
       DOFOR SEX = 'M' 'F'
          SET %S('P'+SEX+AGE) = %IF(t<=2013:1,%S('PR'+SEX+AGE),0.0)  ;*could be 'hppr' or 'PR'SEX+AGE depending on whether USING SMOOTHED PR FOR PRE-2013 VALUES
       END DOFOR SEX
END DOFOR AGE




***********************************************************************************************************************
***EXIT AND ENTRY RATES

* long run trends in exit and entry rates
* note that we follow the Burniaux convention and refer to
* an exit between ages x,x+4 to x+5,x+9 as the exit rate for those aged x,x+4



    do AGES = 15,64,5
          COMPUTE LABEL = %STRING(AGES)+%STRING(AGES+4)
          COMPUTE LABEL2 = %STRING(AGES+5)+%STRING(AGES+9)

          set %s('NEXM'+LABEL) = 0.0   ;* NET EXIT RATES
          set %s('NEXF'+LABEL) = 0.0
          set %s('NENTM'+LABEL) = 0.0   ;* NET ENTRY RATES
          set %s('NENTF'+LABEL) = 0.0
    end do ages


    set %s('NEXF6569') = 0.0
    set %s('NEXM6569') = 0.0
    set %s('NENTF6569') = 0.0
    set %s('NENTM6569') = 0.0

* IMPORTANT NOTE
*
* THERE ARE 2 CHOICES FOR CALCULATING EXIT RATES
* (1) USE UNSMOOTHED DATA (AS IN BURNIAUX ET AL.) BUT THIS RESULTS IN VOLATILE EXIT RATES THAT
* COULD BE INFLUENCED BY THE ECONOMIC CYCLE AND SURVEY SAMPLING & NON-SAMPLING ERRORS; OR
* USE A SMOOTHED SET OF PARTICIPATION RATES IN WHICH THESE PROBLEMS ARE REDUCED, BUT WHERE
* THE SMOOTHING INTRODUCES POTENTIALLY SPURIOUS EFFECTS.
*
* IF USING SMOOTHED DATA THEN USE PART = 'HPPR' ELSE 'PR'

COMPUTE PART = 'PR'


*Note that NEXF1519 is the net exit (entry) rate for people from 15-19 to 20-24, and similarty NEXF6569 is the net  exit (entry rate) for people from age 65-69 to 70+
*As noted below, given that there is no data for PR for 10-14 year olds, PR1519 is projected directly, and then can be used to estimate PRs for later ages using the projected
*exit and entry rates.

    do time = 1984:1,2013:1,1
         do AGES = 15,64,5
             COMPUTE LABEL = %STRING(AGES)+%STRING(AGES+4)
             COMPUTE LABEL2 = %STRING(AGES+5)+%STRING(AGES+9)
             compute %s('NEXF'+LABEL)(time) = 1.0-%S(PART+'F'+LABEL2)(time)/%S(PART+'F'+LABEL)(time-5)
             compute %s('NEXM'+LABEL)(time) = 1.0-%S(PART+'M'+LABEL2)(time)/%S(PART+'M'+LABEL)(time-5)
             compute %s('NEXF6569')(time) = 1.0-%s(PART+'F70')(time)/%s(PART+'F6569')(time-5)
             compute %s('NEXM6569')(time) = 1.0-%s(PART+'M70')(time)/%s(PART+'M6569')(time-5)
             compute %s('NENTF'+LABEL)(time) = (%S(PART+'F'+LABEL2)(time)-%S(PART+'F'+LABEL)(time-5))/(FEMALEP-%S(PART+'F'+LABEL)(time-5))
             compute %s('NENTM'+LABEL)(time) = (%S(PART+'M'+LABEL2)(time)-%S(PART+'M'+LABEL)(time-5))/(MALEP-%S(PART+'M'+LABEL)(time-5))
             compute %s('NENTF6569')(time) = (%S(PART+'F70')(time)-%S(PART+'F6569')(time-5))/(FEMALEP-%S(PART+'F6569')(time-5))
             compute %s('NENTM6569')(time) = (%S(PART+'M70')(time)-%S(PART+'M6569')(time-5))/(MALEP-%S(PART+'M6569')(time-5))
        END DO AGES
    end do time

* Make a choice of whether to asterisk line 1/3 or line 2/4 below.
* IF USING SMOOTHED PARTICIPATION RATES, THEN DON'T NEED TO SMOOTH ENTRY OR EXIT RATES (asterisk line 1/3 and unasterisk line 2/4)
* IF USING UNSMOOTHED PARTICIPATION RATES, THEN unASTERISK line 1/3 and asterisk line 2/4 TO USE SMOOTHED ENTRY/EXIT RATES

   DOFOR AGE =  '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569'
       DOFOR SEX = 'M' 'F'
          @HPFILTER(LAMBDA=50)  %S('NEX'+SEX+age)  1984:1  2013:1  %S('HPNEX'+SEX+AGE) ;* line 1
          *SET %S('HPNEX'+SEX+age)  = %S('NEX'+SEX+age) ;* line 2
          SET %S('DHPNEX'+SEX+AGE) = %S('HPNEX'+SEX+AGE)-%S('HPNEX'+SEX+AGE)(T-1)
          SET %S('DDHPNEX'+SEX+AGE) = %S('DHPNEX'+SEX+AGE)-%S('DHPNEX'+SEX+AGE)(T-1)
          @HPFILTER(LAMBDA=50)  %S('NENT'+SEX+age)  1984:1  2013:1  %S('HPNENT'+SEX+AGE) ;* line 3
          *SET %S('HPNENT'+SEX+AGE) = %S('NENT'+SEX+age) ;* line 4
          SET %S('DHPNENT'+SEX+AGE) = %S('HPNENT'+SEX+AGE)-%S('HPNENT'+SEX+AGE)(T-1)
          SET %S('DDHPNENT'+SEX+AGE) = %S('DHPNENT'+SEX+AGE)-%S('DHPNENT'+SEX+AGE)(T-1)
        END DOFOR SEX
    END DOFOR AGE
************************************000000000000000000000000******************************************
/*

*GRAPHS
*GRAPH Historical Part RATES
grparm AXISlabelling 28 keylabelling 28 subheader 28
SPGRAPH(HFIELD=3,vfield=4)
DOFOR AGE =  '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569'
COMPUTE SUBHEADER = 'Males    '+age+'  years   '
graph(subheader=subheader,noPATTERns,DATES,VTICKS=5) 2
# %S('prm'+age) 1984:1 2013:1  1
# %S('hpprm'+age) 1984:1 2013:1  1
END dofor AGE
SPGRAPH(DONE)

grparm AXISlabelling 28 keylabelling 28 subheader 28
SPGRAPH(HFIELD=3,vfield=4)
DOFOR AGE =  '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569'
COMPUTE SUBHEADER = 'females    '+age+'  years   '
graph(subheader=subheader,noPATTERns,DATES,VTICKS=5) 2
# %S('prf'+age) 1984:1 2013:1  1
# %S('hpprf'+age) 1984:1 2013:1  1
END dofor AGE
SPGRAPH(DONE)

grparm AXISlabelling 28 keylabelling 28 subheader 28
SPGRAPH(HFIELD=3,vfield=4)
DOFOR AGE =  '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569'
COMPUTE SUBHEADER = 'both sexes    '+age+'  years   '
graph(subheader=subheader,noPATTERns,DATES,VTICKS=5) 4
# %S('prm'+age) 1984:1 2013:1  1
# %S('hpprm'+age) 1984:1 2013:1  1
# %S('prf'+age) 1984:1 2013:1  3
# %S('hpprf'+age) 1984:1 2013:1  4
END dofor AGE
SPGRAPH(DONE)


*GRAPHS
*GRAPH NET EXIT RATES
grparm AXISlabelling 28 keylabelling 28 subheader 28
SPGRAPH(HFIELD=3,vfield=4)
DOFOR AGE =  '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569'
COMPUTE SUBHEADER = 'Net exits FEM=RED, MALE=BLK    '+age+'  years   '
graph(subheader=subheader,noPATTERns,DATES,VTICKS=5) 2
# %S('NEXF'+age) 1984:1 2013:1  4
# %S('NEXM'+age) 1984:1 2013:1  1
END dofor AGE
SPGRAPH(DONE)

*GRAPH NET entry RATES
grparm AXISlabelling 28 keylabelling 28 subheader 28
SPGRAPH(HFIELD=3,vfield=4)
DOFOR AGE =  '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569'
COMPUTE SUBHEADER = 'Net ENTRIES FEM=RED, MALE=BLK    '+age+'  years   '
graph(subheader=subheader,noPATTERns,DATES,VTICKS=5) 2
# %S('NEntF'+age) 1984:1 2013:1  4
# %S('NENTM'+age) 1984:1 2013:1  1
END dofor AGE
SPGRAPH(DONE)

*GRAPHS
*GRAPH NET EXIT RATES for older workers
grparm AXISlabelling 28 keylabelling 28 subheader 28
SPGRAPH(HFIELD=2,vfield=3)
DOFOR AGE =  '4549' '5054' '5559' '6064' '6569'
COMPUTE SUBHEADER = 'Net exits FEM=RED, MALE=BLK    '+age+'  years   '
graph(subheader=subheader,noPATTERns,DATES,VTICKS=5) 4
# %S('NEXF'+age) 1984:1 2013:1  1
# %S('hpNEXF'+age) 1984:1 2013:1  1
# %S('NEXm'+age) 1984:1 2013:1  2
# %S('hpNEXM'+age) 1984:1 2013:1  2
END dofor AGE
SPGRAPH(DONE)

* copy older people's exit rates data to an output file
open copy "OUTPUT Exit rates for older workers 1983-84 to 2013-13.XLS"
copy(dates,format=xls,org=columns) 1984:1 2013:1 $
NEXf4549 NEXm4549  $
NEXf5054 NEXm5054  $
NEXf5559 NEXm5559  $
NEXf6064 NEXm6064  $
NEXf6569 NEXm6569  $
HPNEXf4549 HPNEXm4549  $
HPNEXf5054 HPNEXm5054  $
HPNEXf5559 HPNEXm5559  $
HPNEXf6064 HPNEXm6064  $
HPNEXf6569 HPNEXm6569





graph(subheader='1519',noPATTERns,VTICKS=5,dates) 2
# NENTF1519 1984:1 2013:1  4
# NENTM1519 1984:1 2013:1  1

*GRAPH SELECT CASES WHERE MALE NET EXITS ARE +VE IN THE LONG RUN
DOFOR POSEXIT = 'M3034' 'M3539' 'M4044' 'M4549' 'M5054' $
'M5559' 'M6064' 'M6569'
grparm AXISlabelling 12 keylabelling 12 subheader 12
SPGRAPH(vfield=3)
COMPUTE SUBHEADER = POSEXIT+'MALE NET EXITS'
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 2
# %S('NEX'+POSEXIT) 1984:1 2013:1  1
# %S('HPNEX'+POSEXIT) 1984:1 2013:1  4
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 1
# %S('DHPNEX'+POSEXIT) 1985:1 2013:1  1
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 1
# %S('DDHPNEX'+POSEXIT) 1986:1 2013:1  1
SPGRAPH(DONE)
END DOFOR POSEXIT

*GRAPH SELECT CASES WHERE FEMALE NET EXITS ARE +VE IN THE LONG RUN

DOFOR POSEXIT = 'F2529' 'F4549' 'F5054' 'F5559' 'F6064' 'F6569'
grparm AXISlabelling 12 keylabelling 12 subheader 12
SPGRAPH(vfield=3)
COMPUTE SUBHEADER = POSEXIT+' FEMALE NET EXITS'
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 2
# %S('NEX'+POSEXIT) 1984:1 2013:1  1
# %S('HPNEX'+POSEXIT) 1984:1 2013:1  4
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 1
# %S('DHPNEX'+POSEXIT) 1985:1 2013:1  1
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 1
# %S('DDHPNEX'+POSEXIT) 1986:1 2013:1  1
SPGRAPH(DONE)
END DOFOR POSEXIT


*GRAPH SELECT CASES WHERE MALE NET ENTRIES ARE +VE IN THE LONG RUN

DOFOR POSENT = 'M1519' 'M2024' 'M2529'
grparm AXISlabelling 12 keylabelling 12 subheader 12
SPGRAPH(vfield=3)
COMPUTE SUBHEADER = POSENT+' MALE NET ENTRIES'
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 2
# %S('NENT'+POSENT) 1984:1 2013:1  1
# %S('HPNENT'+POSENT) 1984:1 2013:1  4
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 1
# %S('DHPNENT'+POSENT) 1985:1 2013:1  1
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 1
# %S('DDHPNENT'+POSENT) 1986:1 2013:1  1
SPGRAPH(DONE)
END DOFOR POSENT


*GRAPH SELECT CASES WHERE FEMALE NET ENTRIES ARE +VE IN THE LONG RUN

DOFOR POSENT = 'F1519' 'F2024' 'F3034' 'F3539' 'F4044'
grparm AXISlabelling 12 keylabelling 12 subheader 12
SPGRAPH(vfield=3)
COMPUTE SUBHEADER = POSENT+' FEMALE POS ENTRY RATES'
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 2
# %S('NENT'+POSENT) 1984:1 2013:1  1
# %S('HPNENT'+POSENT) 1984:1 2013:1  4
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 1
# %S('DHPNENT'+POSENT) 1985:1 2013:1  1
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 1
# %S('DDHPNENT'+POSENT) 1986:1 2013:1  1
SPGRAPH(DONE)
END DOFOR POSENT
*This ends the main diagnostic graph section


*/

**********************000000000000000000000000000000000000000000*****************************

*****************************0000000000000000*************************************************************
* GRAPH PARTICIPATION RATES FOR 15-19 YEAR OLDS SINCE THERE ARE NO ENTRY RATES FOR 10-14 YR OLDS
* WE THEREFORE NEED A BASE ESTIMATE FOR THIS GROUP OVER TIME
* ONE POSSIBILITY IS THE CURRENT LEVEL - BUT A FORECAST WOULD BE BETTER
DOFOR SEX = 'M' 'F'
          SET %S('DHPPR'+SEX+'1519')  = %S('HPPR'+SEX+'1519')-%S('HPPR'+SEX+'1519')(T-1)
          SET %S('DDHPPR'+SEX+'1519')  = %S('DHPPR'+SEX+'1519')-%S('DHPPR'+SEX+'1519')(T-1)
END DOFOR SEX


*graph 2
*# prf1519
*# prm1519
*SOURCE(NOECHO) "bjautofit.SRC"
*@bjautofit(constant,pmax=3,qmax=3,crit=sbc) prf1519
*BOXJENK(DIFFS=0,AR=1,MA=0) PRF1519

/*
*GRAPHS
DOFOR SEX = 'M' 'F'
grparm AXISlabelling 12 keylabelling 12 subheader 12
SPGRAPH(Vfield=3)
COMPUTE SUBHEADER = SEX+'  1519 YR OLDS  '
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 2
# %S('HPPR'+SEX+'1519') 1984:1 2013:1  1
# %S('PR'+SEX+'1519') 1984:1 2013:1  4
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 1
# %S('DHPPR'+SEX+'1519') 1985:1 2013:1  1
graph(subheader=subheader,noPATTERns,VTICKS=5,dates) 1
# %S('DDHPPR'+SEX+'1519') 1986:1 2013:1  1
SPGRAPH(DONE)
END DOFOR SEX
*/

***********************************************************************************************************************************************************
* NOW use AR1 process and male/female convergence OR estimate Richards curve
***********************************************************************************************************************************************************
*estimate parrticipation rates directly for 1519 year olds
COMPUTE AGE = '1519'
COMPUTE SEX = 'M'
SET %S('PLIM'+SEX+AGE) = 0.52
SET %S('PST'+SEX+AGE) = 2003:1
SET %S('PFLEX'+SEX+AGE) = 2012:1
COMPUTE SEX = 'F'  ;* only used if AR1 not used
SET %S('PLIM'+SEX+AGE) = 0.55
SET %S('PST'+SEX+AGE) = 2005:1
SET %S('PFLEX'+SEX+AGE) = 2012:1

* prf1519 looks more like an AR1 process than a logistic. It could be included below by setting: DOFOR PCHANGE = 'F1519' 'M1519'
* but the default is to use the AR1 for females and to match the male PR to te female so they do not diverge
linreg(define=AR1,NOPRINT) prf1519
# constant prf1519{1}
uforecast(equation=ar1,noprint) forf1519_ar1 2014:1 2060:1
graph(header="Forecasts vs Actuals",key=upleft) 2
# prf1519
# forf1519_ar1
SET FPF1519 = FORF1519_AR1
set lprf1519 = log(prf1519)
set lprm1519 = log(prm1519)
linreg(noprint) lprm1519  2003:1 2013:1
# constant lprf1519
set fpm1519 = exp(%beta(1))*fpf1519^(%beta(2))

*disp fpm1519(2060:1) fpf1519(2060:1)


*SET TREND = T
*DOFOR PCHANGE = 'F1519' 'M1519'
*
*   COMPUTE K = FIX(%S('PST'+PCHANGE)(1))  ;* POINT OF THE STRUCTURAL BREAK
*   SET TREND2 = TREND-K   ;* RESETS T SO THAT IT IS ZERO AT THE POINT WHERE A STRUCTURAL BREAK HAS BEEN DETECTED
*   COMPUTE FLEX = %S('PFLEX'+PCHANGE)(2013:1)-K  ;* THE ESTIMATED INFLECTION POINT OF THE RICHARDS RELATIVE TO THE CORRECTED STARTING VALUE
*   SET HP = %S('HPPR'+PCHANGE)   ;* SMOOTHED (HODRICK-PRESCOTT) PARTICIPATION RATES
*   COMPUTE POS = %IF(HP(2013:1)-HP(K)>0,1.0,-1.0)
*   COMPUTE LIM = %S('PLIM'+PCHANGE)(2013:1);* THIS IS THE MAX OR MIN VALUE OF THE NET EXIT RATE
*   COMPUTE SIGN = %IF(LIM<0,-1.0,1.0)
*
*   COMPUTE LAMBDA = -1.0  ;* INITIAL STATES OF RICHARDS PARAMETERS FOR NLLS. lambda = -1 IS THE LOGISTIC
*   COMPUTE PHI = -3.0 ;* THIS MEANS THAT THE INITIAL VALUE OF PHI IS S.T. THE LONG RUN IS AROUND 95% OF THE LIMIT
*   COMPUTE GROW = SQRT(0.15)
*  * DISP K FLEX POS LIM SIGN LAMBDA PHI GROW
*
*   NONLIN GROW PHI LAMBDA
*   FRML G = -GROW*GROW
*   FRML BETA = (-1.0/LAMBDA)*EXP(-G*FLEX) ;* BASED ON THE RELATIONSHIP BETWEEN BETA AND G AT THE INFLECTION POINT OF A RICHARDS
*   FRML LONG =  HP(2013:1)+(1/(1+EXP(PHI)))*(LIM-HP(2013:1))  ;* provides a boundary on the limit of the curve
*   FRML ALPHA = (HP(2013:1)-LONG)/(((1+BETA*exp(-GROW*GROW*TREND2(2013:1)))^LAMBDA)-1)
*   FRML CON =  LONG-ALPHA
*   FRML F1 HP = CON+ALPHA*(1.0+BETA*EXP(G*TREND2))^LAMBDA
*   nlls(NOPRINT,frml=f1,ITERATIONS=10000,method=SIMPLEX,cvcrit=0.0000001) HP K 2013:1
*   SET %S('FP'+PCHANGE) = CON+ALPHA*(1.0+BETA*EXP(G*TREND2))^LAMBDA
*   *DISP PCHANGE  'BETA= ' (-1.0/LAMBDA)*EXP(-(-GROW*GROW)*FLEX)  'PHI= ' PHI 'G= ' GROW 'LAMBDA = ' LAMBDA 'LIMIT= ' LIM
*
*GRAPH(SUBHEADER=PCHANGE) 2
*# %S('FP'+PCHANGE) K 2060:1
*# HP k 2013:1
*end dofor pchange


*These are the resulting estimates of projected participation rates for 15-19 year olds
COMPUTE AGE = '1519'
DOFOR SEX = 'M' 'F'
   SET %S('P'+SEX+AGE) = %IF(t<=2013:1,%S('PR'+SEX+AGE),%S('FP'+SEX+AGE))
END DOFOR SEX


*GRAPH(SUBHEADER='Prate females 15-19')  2
*# Pf1519 1979:1 2060:1
*# PRf1519 1979:1 2060:1
*
*GRAPH 2
*# PF1519 1982:1 2020:1
*# PM1519 1982:1 2020:1

**************************************00000000000000000000000000****************************************************


*Estimate transition to long-run exit and entry rates
* INITIALISING STARTING VALUE AND FLEXPOINTS FOR SIGMOID ESTIMATION


*********** MALES EXIT RATES THAT ARE +VE




SET TREND = T
COMPUTE SEX = 'M'

STATS(NOPRINT) NEXM3539 2005:01 2013:01
SET fm3539 = %MEAN
SET FM4044 = 0.0

COMPUTE LINEAR_END = 2023:1
COMPUTE LOGISTIC_END = LINEAR_END+10
COMPUTE LEND = LOGISTIC_END-2013:1
linreg(NOprint) NEXM4549 1984:1 2013:1   ;* THIS BIT USES A LINEAR REGRESSION TO PROJECT A SERIES FOR 12 STEPS TO 2023
# constant trend
PRJ FC_NEXM4549 1984:1 LINEAR_END
*GRAPH 2
*# NEXM4549 1984:1 2013:1
*# FC_NEXM4549 1984:1 LINEAR_END
compute LR = FC_NEXM4549(LINEAR_END)  ; * IS VALUE OF C IF G>0 AND C+A IF G<0  ;*THEN WE CALCULATE A LOGISTIC PATH TO THE LONG RUN, ASSUMING THAT 2012-13 IS THE INFLEXION POINT
COMPUTE A = %IF(%BETA(2)>0,2.*(LR-FC_NEXM4549(2013:1)),2.*(FC_NEXM4549(2013:1)-LR))
COMPUTE C = %IF(%BETA(2)<0,LR,LR-A)
COMPUTE DEVIATION = %IF(%BETA(2)<0,1.005,0.995) ;* SINCE A LOGISTIC ONLY GOES TO THE LONG RUN AT T GOES TO INFINITY, WE CHOOSE A TARGET THAT IS CLOSE TO THE LONG RUN
* NOTE THAT EVEN IF WE ASSUME THAT WE ADOPT A LONG RUN VALUE DETERMINED BY A LINEAR FORECAST OF 10 STEPS, WE CAN GET THERE BY A LOGISTIC with MANY MORE STEPS, IN THIS CASE 20 (LOGISTIC_END)
COMPUTE GR = %IF(%BETA(2)<0,1./LEND*LOG(A/(C*(DEVIATION-1.))-1.0),1./LEND*LOG(A/(C*(DEVIATION-1.)+A*DEVIATION)-1.0))
SET TREND2 = T-2013:1
SET FM4549 = %IF(T<=(LOGISTIC_END+2013:1),C+A/(1.+EXP(GR*TREND2)),DEVIATION*LR)  ;* USE THE LOGISTIC FROM THE INFLEXION POINT TO GET A SMOOTH TRANSITION WITHIN STRIKING DISTANCE OF THE 'LONG RUN'
*GRAPH 2
*# NEXM4549 1984:1 2013:1
*# FM4549 2013:1 LOGISTIC_END+15





COMPUTE LINEAR_END = 2018:1
COMPUTE LOGISTIC_END = LINEAR_END+10
COMPUTE LEND = LOGISTIC_END-2013:1
linreg(NOprint) NEXM5054 2001:1 2013:1   ;* THIS BIT USES A LINEAR REGRESSION TO PROJECT A SERIES FOR 12 STEPS TO 2023
# constant trend
PRJ FC_NEXM5054 1984:1 LINEAR_END
*GRAPH 2
*# NEXM5054 1984:1 2013:1
*# FC_NEXM5054 1984:1 LINEAR_END
compute LR = FC_NEXM5054(LINEAR_END)  ; * IS VALUE OF C IF G>0 AND C+A IF G<0  ;*THEN WE CALCULATE A LOGISTIC PATH TO THE LONG RUN, ASSUMING THAT 2012-13 IS THE INFLEXION POINT
COMPUTE A = %IF(%BETA(2)>0,2.*(LR-FC_NEXM5054(2013:1)),2.*(FC_NEXM5054(2013:1)-LR))
COMPUTE C = %IF(%BETA(2)<0,LR,LR-A)
COMPUTE DEVIATION = %IF(%BETA(2)<0,1.005,0.995) ;* SINCE A LOGISTIC ONLY GOES TO THE LONG RUN AT T GOES TO INFINITY, WE CHOOSE A TARGET THAT IS CLOSE TO THE LONG RUN
* NOTE THAT EVEN IF WE ASSUME THAT WE ADOPT A LONG RUN VALUE DETERMINED BY A LINEAR FORECAST OF 10 STEPS, WE CAN GET THERE BY A LOGISTIC with MANY MORE STEPS, IN THIS CASE 20 (LOGISTIC_END)
COMPUTE GR = %IF(%BETA(2)<0,1./LEND*LOG(A/(C*(DEVIATION-1.))-1.0),1./LEND*LOG(A/(C*(DEVIATION-1.)+A*DEVIATION)-1.0))
SET TREND2 = T-2013:1
SET FM5054 = %IF(T<=(LOGISTIC_END+2013:1),C+A/(1.+EXP(GR*TREND2)),DEVIATION*LR)  ;* USE THE LOGISTIC FROM THE INFLEXION POINT TO GET A SMOOTH TRANSITION WITHIN STRIKING DISTANCE OF THE 'LONG RUN'
*GRAPH 2
*# NEXM5054 1984:1 2013:1
*# FM5054 2013:1 LOGISTIC_END+15

COMPUTE LINEAR_END = 2023:1
COMPUTE LOGISTIC_END = LINEAR_END+10
COMPUTE LEND = LOGISTIC_END-2013:1
linreg(NOprint) NEXM5559 1984:1 2013:1   ;* THIS BIT USES A LINEAR REGRESSION TO PROJECT A SERIES FOR 12 STEPS TO 2023
# constant trend
PRJ FC_NEXM5559 1984:1 LINEAR_END
*GRAPH 2
*# NEXM5559 1984:1 2013:1
*# FC_NEXM5559 1984:1 LINEAR_END
compute LR = FC_NEXM5559(LINEAR_END)  ; * IS VALUE OF C IF G>0 AND C+A IF G<0  ;*THEN WE CALCULATE A LOGISTIC PATH TO THE LONG RUN, ASSUMING THAT 2012-13 IS THE INFLEXION POINT
COMPUTE A = %IF(%BETA(2)>0,2.*(LR-FC_NEXM5559(2013:1)),2.*(FC_NEXM5559(2013:1)-LR))
COMPUTE C = %IF(%BETA(2)<0,LR,LR-A)
COMPUTE DEVIATION = %IF(%BETA(2)<0,1.005,0.995) ;* SINCE A LOGISTIC ONLY GOES TO THE LONG RUN AT T GOES TO INFINITY, WE CHOOSE A TARGET THAT IS CLOSE TO THE LONG RUN
* NOTE THAT EVEN IF WE ASSUME THAT WE ADOPT A LONG RUN VALUE DETERMINED BY A LINEAR FORECAST OF 10 STEPS, WE CAN GET THERE BY A LOGISTIC with MANY MORE STEPS, IN THIS CASE 20 (LOGISTIC_END)
COMPUTE GR = %IF(%BETA(2)<0,1./LEND*LOG(A/(C*(DEVIATION-1.))-1.0),1./LEND*LOG(A/(C*(DEVIATION-1.)+A*DEVIATION)-1.0))
SET TREND2 = T-2013:1
SET FM5559 = %IF(T<=(LOGISTIC_END+2013:1),C+A/(1.+EXP(GR*TREND2)),DEVIATION*LR)  ;* USE THE LOGISTIC FROM THE INFLEXION POINT TO GET A SMOOTH TRANSITION WITHIN STRIKING DISTANCE OF THE 'LONG RUN'
*GRAPH 2
*# NEXM5559 1984:1 2013:1
*# FM5559 2013:1 LOGISTIC_END+15

COMPUTE LINEAR_END = 2018:1
COMPUTE LOGISTIC_END = LINEAR_END+10
COMPUTE LEND = LOGISTIC_END-2013:1
linreg(NOprint) NEXM6064 1984:1 2013:1   ;* THIS BIT USES A LINEAR REGRESSION TO PROJECT A SERIES FOR 12 STEPS TO 2023
# constant trend
PRJ FC_NEXM6064 1984:1 LINEAR_END
*GRAPH 2
*# NEXM6064 1984:1 2013:1
*# FC_NEXM6064 1984:1 LINEAR_END
compute LR = FC_NEXM6064(LINEAR_END)  ; * IS VALUE OF C IF G>0 AND C+A IF G<0  ;*THEN WE CALCULATE A LOGISTIC PATH TO THE LONG RUN, ASSUMING THAT 2012-13 IS THE INFLEXION POINT
COMPUTE A = %IF(%BETA(2)>0,2.*(LR-FC_NEXM6064(2013:1)),2.*(FC_NEXM6064(2013:1)-LR))
COMPUTE C = %IF(%BETA(2)<0,LR,LR-A)
COMPUTE DEVIATION = %IF(%BETA(2)<0,1.005,0.995) ;* SINCE A LOGISTIC ONLY GOES TO THE LONG RUN AT T GOES TO INFINITY, WE CHOOSE A TARGET THAT IS CLOSE TO THE LONG RUN
* NOTE THAT EVEN IF WE ASSUME THAT WE ADOPT A LONG RUN VALUE DETERMINED BY A LINEAR FORECAST OF 10 STEPS, WE CAN GET THERE BY A LOGISTIC with MANY MORE STEPS, IN THIS CASE 20 (LOGISTIC_END)
COMPUTE GR = %IF(%BETA(2)<0,1./LEND*LOG(A/(C*(DEVIATION-1.))-1.0),1./LEND*LOG(A/(C*(DEVIATION-1.)+A*DEVIATION)-1.0))
SET TREND2 = T-2013:1
SET FM6064 = %IF(T<=(LOGISTIC_END+2013:1),C+A/(1.+EXP(GR*TREND2)),DEVIATION*LR)  ;* USE THE LOGISTIC FROM THE INFLEXION POINT TO GET A SMOOTH TRANSITION WITHIN STRIKING DISTANCE OF THE 'LONG RUN'
*GRAPH 2
*# NEXM6064 1984:1 2013:1
*# FM6064 2013:1 LOGISTIC_END+15





COMPUTE LINEAR_END = 2028:1
COMPUTE LOGISTIC_END = LINEAR_END+10
COMPUTE LEND = LOGISTIC_END-2013:1
linreg(NOprint) NEXM6569 1990:1 2013:1   ;* THIS BIT USES A LINEAR REGRESSION TO PROJECT A SERIES FOR 12 STEPS TO 2023
# constant trend
PRJ FC_NEXM6569 1990:1 LINEAR_END
*GRAPH 2
*# NEXM6569 1990:1 2013:1
*# FC_NEXM6569 1990:1 LINEAR_END
compute LR = FC_NEXM6569(LINEAR_END)  ; * IS VALUE OF C IF G>0 AND C+A IF G<0  ;*THEN WE CALCULATE A LOGISTIC PATH TO THE LONG RUN, ASSUMING THAT 2012-13 IS THE INFLEXION POINT
COMPUTE A = %IF(%BETA(2)>0,2.*(LR-FC_NEXM6569(2013:1)),2.*(FC_NEXM6569(2013:1)-LR))
COMPUTE C = %IF(%BETA(2)<0,LR,LR-A)
COMPUTE DEVIATION = %IF(%BETA(2)<0,1.005,0.995) ;* SINCE A LOGISTIC ONLY GOES TO THE LONG RUN AT T GOES TO INFINITY, WE CHOOSE A TARGET THAT IS CLOSE TO THE LONG RUN
* NOTE THAT EVEN IF WE ASSUME THAT WE ADOPT A LONG RUN VALUE DETERMINED BY A LINEAR FORECAST OF 10 STEPS, WE CAN GET THERE BY A LOGISTIC with MANY MORE STEPS, IN THIS CASE 20 (LOGISTIC_END)
COMPUTE GR = %IF(%BETA(2)<0,1./LEND*LOG(A/(C*(DEVIATION-1.))-1.0),1./LEND*LOG(A/(C*(DEVIATION-1.)+A*DEVIATION)-1.0))
SET TREND2 = T-2013:1
SET FM6569 = %IF(T<=(LOGISTIC_END),C+A/(1.+EXP(GR*TREND2)),DEVIATION*LR)  ;* USE THE LOGISTIC FROM THE INFLEXION POINT TO GET A SMOOTH TRANSITION WITHIN STRIKING DISTANCE OF THE 'LONG RUN'
*GRAPH 2
*# NEXM6569 1984:1 2013:1
*# FM6569 2013:1 LOGISTIC_END+15



**********MALES WITH +VE NET ENTRY RATES IN THE LONG RUN

COMPUTE SEX = 'M'

SET %S('F'+SEX+'1519') = 0.55
STATS(NOPRINT) NENTM2024 1995:01 2013:01
SET %S('F'+SEX+'2024') = %MEAN
SET %S('F'+SEX+'2529') = 0.2

COMPUTE LINEAR_END = 2023:1
COMPUTE LOGISTIC_END = LINEAR_END+5
COMPUTE LEND = LOGISTIC_END-2013:1
linreg(NOprint) NENTM3034 1984:1 2013:1   ;* THIS BIT USES A LINEAR REGRESSION TO PROJECT A SERIES FOR 12 STEPS TO 2023
# constant trend
PRJ FC_NENTM3034 1984:1 LINEAR_END
*GRAPH 2
*# NENTM3034 1984:1 2013:1
*# FC_NENTM3034 1984:1 LINEAR_END
compute LR = FC_NENTM3034(LINEAR_END)  ; * IS VALUE OF C IF G>0 AND C+A IF G<0  ;*THEN WE CALCULATE A LOGISTIC PATH TO THE LONG RUN, ASSUMING THAT 2012-13 IS THE INFLEXION POINT
COMPUTE A = %IF(%BETA(2)>0,2.*(LR-FC_NENTM3034(2013:1)),2.*(FC_NENTM3034(2013:1)-LR))
COMPUTE C = %IF(%BETA(2)<0,LR,LR-A)
COMPUTE DEVIATION = %IF(%BETA(2)<0,1.005,0.995) ;* SINCE A LOGISTIC ONLY GOES TO THE LONG RUN AT T GOES TO INFINITY, WE CHOOSE A TARGET THAT IS CLOSE TO THE LONG RUN
* NOTE THAT EVEN IF WE ASSUME THAT WE ADOPT A LONG RUN VALUE DETERMINED BY A LINEAR FORECAST OF 10 STEPS, WE CAN GET THERE BY A LOGISTIC with MANY MORE STEPS, IN THIS CASE 20 (LOGISTIC_END)
COMPUTE GR = %IF(%BETA(2)<0,1./LEND*LOG(A/(C*(DEVIATION-1.))-1.0),1./LEND*LOG(A/(C*(DEVIATION-1.)+A*DEVIATION)-1.0))
SET TREND2 = T-2013:1
SET Fm3034 = %IF(T<=(LOGISTIC_END+2013:1),C+A/(1.+EXP(GR*TREND2)),DEVIATION*LR)  ;* USE THE LOGISTIC FROM THE INFLEXION POINT TO GET A SMOOTH TRANSITION WITHIN STRIKING DISTANCE OF THE 'LONG RUN'
*GRAPH 2
*# NENTM3034 1984:1 2013:1
*# Fm3034 2013:1 LOGISTIC_END+15


*************** FEMALE EXIT RATES THAT ARE +VE *******************************************

COMPUTE SEX = 'F'

SET %S('F'+SEX+'2529') = NEXF2529(2009:1) ;* SHOULD FALL GIVEN SHIFT IN CHILD CARING AND HIGHER EDUCATIONAL ATTAINMENT FROM PREVIOUS LABOUR WITHDRAWAL
SET %S('F'+SEX+'4549') = HPNEXF4549(2013:1)



COMPUTE LINEAR_END = 2020:1
COMPUTE LOGISTIC_END = LINEAR_END+5
COMPUTE LEND = LOGISTIC_END-2013:1
linreg(NOprint) NEXF5054 1984:1 2013:1   ;* THIS BIT USES A LINEAR REGRESSION TO PROJECT A SERIES FOR 12 STEPS TO 2023
# constant trend
PRJ FC_NEXF5054 1984:1 LINEAR_END
*GRAPH 2
*# NEXF5054 1984:1 2013:1
*# FC_NEXF5054 1984:1 LINEAR_END
compute LR = FC_NEXF5054(LINEAR_END)  ; * IS VALUE OF C IF G>0 AND C+A IF G<0  ;*THEN WE CALCULATE A LOGISTIC PATH TO THE LONG RUN, ASSUMING THAT 2012-13 IS THE INFLEXION POINT
COMPUTE A = %IF(%BETA(2)>0,2.*(LR-FC_NEXF5054(2013:1)),2.*(FC_NEXF5054(2013:1)-LR))
COMPUTE C = %IF(%BETA(2)<0,LR,LR-A)
COMPUTE DEVIATION = %IF(%BETA(2)<0,1.005,0.995) ;* SINCE A LOGISTIC ONLY GOES TO THE LONG RUN AT T GOES TO INFINITY, WE CHOOSE A TARGET THAT IS CLOSE TO THE LONG RUN
* NOTE THAT EVEN IF WE ASSUME THAT WE ADOPT A LONG RUN VALUE DETERMINED BY A LINEAR FORECAST OF 10 STEPS, WE CAN GET THERE BY A LOGISTIC with MANY MORE STEPS, IN THIS CASE 20 (LOGISTIC_END)
COMPUTE GR = %IF(%BETA(2)<0,1./LEND*LOG(A/(C*(DEVIATION-1.))-1.0),1./LEND*LOG(A/(C*(DEVIATION-1.)+A*DEVIATION)-1.0))
SET TREND2 = T-2013:1
SET FF5054 = %IF(T<=(LOGISTIC_END+2013:1),C+A/(1.+EXP(GR*TREND2)),DEVIATION*LR)  ;* USE THE LOGISTIC FROM THE INFLEXION POINT TO GET A SMOOTH TRANSITION WITHIN STRIKING DISTANCE OF THE 'LONG RUN'
*GRAPH 2
*# NEXF5054 1984:1 2013:1
*# FF5054 2013:1 LOGISTIC_END+15



COMPUTE LINEAR_END = 2018:1
COMPUTE LOGISTIC_END = LINEAR_END+10
COMPUTE LEND = LOGISTIC_END-2013:1
linreg(NOprint) NEXF5559 1984:1 2013:1   ;* THIS BIT USES A LINEAR REGRESSION TO PROJECT A SERIES FOR 12 STEPS TO 2023
# constant trend
PRJ FC_NEXF5559 1984:1 LINEAR_END
*GRAPH 2
*# NEXF5559 1984:1 2013:1
*# FC_NEXF5559 1984:1 LINEAR_END
compute LR = FC_NEXF5559(LINEAR_END)  ; * IS VALUE OF C IF G>0 AND C+A IF G<0  ;*THEN WE CALCULATE A LOGISTIC PATH TO THE LONG RUN, ASSUMING THAT 2012-13 IS THE INFLEXION POINT
COMPUTE A = %IF(%BETA(2)>0,2.*(LR-FC_NEXF5559(2013:1)),2.*(FC_NEXF5559(2013:1)-LR))
COMPUTE C = %IF(%BETA(2)<0,LR,LR-A)
COMPUTE DEVIATION = %IF(%BETA(2)<0,1.005,0.995) ;* SINCE A LOGISTIC ONLY GOES TO THE LONG RUN AT T GOES TO INFINITY, WE CHOOSE A TARGET THAT IS CLOSE TO THE LONG RUN
* NOTE THAT EVEN IF WE ASSUME THAT WE ADOPT A LONG RUN VALUE DETERMINED BY A LINEAR FORECAST OF 10 STEPS, WE CAN GET THERE BY A LOGISTIC with MANY MORE STEPS, IN THIS CASE 20 (LOGISTIC_END)
COMPUTE GR = %IF(%BETA(2)<0,1./LEND*LOG(A/(C*(DEVIATION-1.))-1.0),1./LEND*LOG(A/(C*(DEVIATION-1.)+A*DEVIATION)-1.0))
SET TREND2 = T-2013:1
SET FF5559 = %IF(T<=(LOGISTIC_END+2013:1),C+A/(1.+EXP(GR*TREND2)),DEVIATION*LR)  ;* USE THE LOGISTIC FROM THE INFLEXION POINT TO GET A SMOOTH TRANSITION WITHIN STRIKING DISTANCE OF THE 'LONG RUN'
*GRAPH 2
*# NEXF5559 1984:1 2013:1
*# FF5559 2013:1 LOGISTIC_END+15


COMPUTE LINEAR_END = 2023:1
COMPUTE LOGISTIC_END = LINEAR_END+5
COMPUTE LEND = LOGISTIC_END-2013:1
linreg(NOprint) NEXF6064 1984:1 2013:1   ;* THIS BIT USES A LINEAR REGRESSION TO PROJECT A SERIES FOR 12 STEPS TO 2024-25
# constant trend
PRJ FC_NEXF6064 1984:1 LINEAR_END
*GRAPH 2
*# NEXF6064 1984:1 2013:1
*# FC_NEXF6064 1984:1 LINEAR_END
compute LR = FC_NEXF6064(LINEAR_END)  ; * IS VALUE OF C IF G>0 AND C+A IF G<0  ;*THEN WE CALCULATE A LOGISTIC PATH TO THE LONG RUN, ASSUMING THAT 2012-13 IS THE INFLEXION POINT
COMPUTE A = %IF(%BETA(2)>0,2.*(LR-FC_NEXF6064(2013:1)),2.*(FC_NEXF6064(2013:1)-LR))
COMPUTE C = %IF(%BETA(2)<0,LR,LR-A)
COMPUTE DEVIATION = %IF(%BETA(2)<0,1.005,0.995) ;* SINCE A LOGISTIC ONLY GOES TO THE LONG RUN AT T GOES TO INFINITY, WE CHOOSE A TARGET THAT IS CLOSE TO THE LONG RUN
* NOTE THAT EVEN IF WE ASSUME THAT WE ADOPT A LONG RUN VALUE DETERMINED BY A LINEAR FORECAST OF 10 STEPS, WE CAN GET THERE BY A LOGISTIC with MANY MORE STEPS, IN THIS CASE 20 (LOGISTIC_END)
COMPUTE GR = %IF(%BETA(2)<0,1./LEND*LOG(A/(C*(DEVIATION-1.))-1.0),1./LEND*LOG(A/(C*(DEVIATION-1.)+A*DEVIATION)-1.0)) ;* CALCULATE THE VALUE OF THE
SET TREND2 = T-2013:1
SET FF6064 = %IF(T<=(LOGISTIC_END+2013:1),C+A/(1.+EXP(GR*TREND2)),DEVIATION*LR)  ;* USE THE LOGISTIC FROM THE INFLEXION POINT TO GET A SMOOTH TRANSITION WITHIN STRIKING DISTANCE OF THE 'LONG RUN'
*GRAPH 2
*# NEXF6064 1984:1 2013:1
*# FF6064 2013:1 LOGISTIC_END+10


SET %S('XLIM'+SEX+'6569') = 0.81
SET %S('XST'+SEX+'6569') = 1997:1
SET %S('XFLEX'+SEX+'6569') = 2002:1

***********FEMALES WITH +VE NET ENTRY RATES IN THE LONG RUN

COMPUTE SEX = 'F'

* MODELING SUGGEST NENTF1519 IS A RANDOM WALK WITHOUT TREND (NOT AN AR PROCESS)

SET FF1519 = NENTF1519(2013:1)
*DISP FF1519(2060:1)

* NENTF2024 PREDICTED TO BE POSITIVE GIVEN SHIFT IN CHILD CARING AND HIGHER EDUCATIONAL ATTAINMENT

COMPUTE LINEAR_END = 2025:1
COMPUTE LOGISTIC_END = LINEAR_END+5
COMPUTE LEND = LOGISTIC_END-2013:1
linreg(NOprint) NENTF2024 1984:1 2013:1   ;* THIS BIT USES A LINEAR REGRESSION TO PROJECT A SERIES FOR 12 STEPS TO 2023
# constant trend
PRJ FC_NENTF2024 1984:1 LINEAR_END
*GRAPH 2
*# NENTF2024 1984:1 2013:1
*# FC_NENTF2024 1984:1 LINEAR_END
compute LR = FC_NENTF2024(LINEAR_END)  ; * IS VALUE OF C IF G>0 AND C+A IF G<0  ;*THEN WE CALCULATE A LOGISTIC PATH TO THE LONG RUN, ASSUMING THAT 2012-13 IS THE INFLEXION POINT
COMPUTE A = %IF(%BETA(2)>0,2.*(LR-FC_NENTF2024(2013:1)),2.*(FC_NENTF2024(2013:1)-LR))
COMPUTE C = %IF(%BETA(2)<0,LR,LR-A)
COMPUTE DEVIATION = %IF(%BETA(2)<0,1.005,0.995) ;* SINCE A LOGISTIC ONLY GOES TO THE LONG RUN AT T GOES TO INFINITY, WE CHOOSE A TARGET THAT IS CLOSE TO THE LONG RUN
* NOTE THAT EVEN IF WE ASSUME THAT WE ADOPT A LONG RUN VALUE DETERMINED BY A LINEAR FORECAST OF 10 STEPS, WE CAN GET THERE BY A LOGISTIC with MANY MORE STEPS, IN THIS CASE 20 (LOGISTIC_END)
COMPUTE GR = %IF(%BETA(2)<0,1./LEND*LOG(A/(C*(DEVIATION-1.))-1.0),1./LEND*LOG(A/(C*(DEVIATION-1.)+A*DEVIATION)-1.0)) ;* CALCULATE THE VALUE OF THE
SET TREND2 = T-2013:1
SET FF2024 = %IF(T<=(LOGISTIC_END+2013:1),C+A/(1.+EXP(GR*TREND2)),DEVIATION*LR)  ;* USE THE LOGISTIC FROM THE INFLEXION POINT TO GET A SMOOTH TRANSITION WITHIN STRIKING DISTANCE OF THE 'LONG RUN'
*GRAPH 2
*# NENTF2024 1984:1 2013:1
*# FF2024 2013:1 LOGISTIC_END+5


STATS(NOPRINT) NENTF3034 2001:01 2013:01
SET %S('F'+SEX+'3034') = %MEAN

COMPUTE LINEAR_END = 2018:1
COMPUTE LOGISTIC_END = LINEAR_END+5
COMPUTE LEND = LOGISTIC_END-2013:1
linreg(NOprint) NENTF3539 1995:1 2013:1   ;* THIS BIT USES A LINEAR REGRESSION TO PROJECT A SERIES FOR 12 STEPS TO 2024-25
# constant trend
PRJ FC_NENTF3539 1984:1 LINEAR_END
*GRAPH 2
*# NENTF3539 1984:1 2013:1
*# FC_NENTF3539 1984:1 LINEAR_END
compute LR = FC_NENTF3539(LINEAR_END)  ; * IS VALUE OF C IF G>0 AND C+A IF G<0  ;*THEN WE CALCULATE A LOGISTIC PATH TO THE LONG RUN, ASSUMING THAT 2012-13 IS THE INFLEXION POINT
COMPUTE A = %IF(%BETA(2)>0,2.*(LR-FC_NENTF3539(2013:1)),2.*(FC_NENTF3539(2013:1)-LR))
COMPUTE C = %IF(%BETA(2)<0,LR,LR-A)
COMPUTE DEVIATION = %IF(%BETA(2)<0,1.005,0.995) ;* SINCE A LOGISTIC ONLY GOES TO THE LONG RUN AT T GOES TO INFINITY, WE CHOOSE A TARGET THAT IS CLOSE TO THE LONG RUN
* NOTE THAT EVEN IF WE ASSUME THAT WE ADOPT A LONG RUN VALUE DETERMINED BY A LINEAR FORECAST OF 10 STEPS, WE CAN GET THERE BY A LOGISTIC with MANY MORE STEPS, IN THIS CASE 20 (LOGISTIC_END)
COMPUTE GR = %IF(%BETA(2)<0,1./LEND*LOG(A/(C*(DEVIATION-1.))-1.0),1./LEND*LOG(A/(C*(DEVIATION-1.)+A*DEVIATION)-1.0)) ;* CALCULATE THE VALUE OF THE
SET TREND2 = T-2013:1
SET FF3539 = %IF(T<=(LOGISTIC_END+2013:1),C+A/(1.+EXP(GR*TREND2)),DEVIATION*LR)  ;* USE THE LOGISTIC FROM THE INFLEXION POINT TO GET A SMOOTH TRANSITION WITHIN STRIKING DISTANCE OF THE 'LONG RUN'
*GRAPH 2
*# NENTF3539 1984:1 2013:1
*# FF3539 2013:1 LOGISTIC_END+10


LINREG(DEFINE=EQ_NENTF4044,NOPRINT) NENTF4044 1984:1 2013:1
# CONSTANT NENTF4044{1}
uforecast(equation=EQ_NENTF4044,noprint) FC_NENTF4044 2014:1 2060:1
*graph(header="Forecasts vs Actuals",key=upleft) 2
*# NENTf4044 1984:1 2013:1
*# FC_NENTF4044 2014:1 2060:1
SET FF4044 = FC_NENTF4044



*******************************************************************
*                                  [1]                            *
*                                                                 *
*                     Estimate EXIT rates for males               *
*                                                                 *
*******************************************************************

* THIS ESTABLISHES THIS GROUP AS A +VE NET EXIT

SET XM3539 = 1.0
SET XM4044 = 1.0
SET XM4549 = 1.0
SET XM5054 = 1.0
SET XM5559 = 1.0
SET XM6064 = 1.0
SET XM6569 = 1.0





*compute sex = 'M'
*DOFOR POSEXIT = '6569'
*	SET %S('X'+SEX+POSEXIT) = 1.0  ;* THIS ESTABLISHES THIS GROUP AS A +VE NET EXIT
*   COMPUTE K = FIX(%S('xst'+sex+posexit)(1))  ;* POINT OF THE STRUCTURAL BREAK
*	SET TREND2 = TREND-K   ;* RESETS T SO THAT IT IS ZERO AT THE POINT WHERE A STRUCTURAL BREAK HAS BEEN DETECTED
*   COMPUTE FLEX = %S('XFLEX'+SEX+POSEXIT)(2013:1)-K  ;* THE ESTIMATED INFLECTION POINT OF THE LOGISTIC RELATIVE TO THE CORRECTED STARTING VALUE
*   SET HP = %S('NEX'+SEX+POSEXIT)   ;* NET EXIT RATE BASED ON SMOOTHED (HODRICK-PRESCOTT) PARTICIPATION RATES
*   COMPUTE POS = %IF(HP(2013:1)-HP(K)>0,1.0,-1.0)
*   COMPUTE LIM = %S('XLIM'+SEX+POSEXIT)(2013:1);* THIS IS THE MAX OR MIN VALUE OF THE NET EXIT RATE
*   COMPUTE SIGN = %IF(LIM<0,-1.0,1.0)
*   * INITIAL STATES OF RICHARDS PARAMETERS FOR NLLS
*   COMPUTE LAMBDA = -1.0  ;* THIS IS THE LOGISTIC
*   COMPUTE PHI = -3.0 ;* THIS MEANS THAT THE INITIAL VALUE OF PHI IS S.T. THE LONG RUN IS AROUND 95% OF THE LIMIT
*   COMPUTE GROW = SQRT(0.15)
*   *DISP K FLEX POS LIM SIGN LAMBDA PHI GROW
*
*
*
*
*   NONLIN GROW PHI LAMBDA
*   FRML G = -GROW*GROW
*   FRML BETA = (-1.0/LAMBDA)*EXP(-G*FLEX) ;* BASED ON THE RELATIONSHIP BETWEEN BETA AND G AT THE INFLECTION POINT OF A RICHARDS
*   FRML LONG =  HP(2013:1)+(1/(1+EXP(PHI)))*(LIM-HP(2013:1))
*   FRML ALPHA = (HP(2013:1)-LONG)/(((1+BETA*exp(-GROW*GROW*TREND2(2013:1)))^LAMBDA)-1)
*   FRML CON =  LONG-ALPHA
*   FRML F1 HP = CON+ALPHA*(1.0+BETA*EXP(G*TREND2))^LAMBDA
*   nlls(NOPRINT,frml=f1,ITERATIONS=10000,method=SIMPLEX) HP K 2013:1
*   SET %S('F'+SEX+POSEXIT) = CON+ALPHA*(1.0+BETA*EXP(G*TREND2))^LAMBDA
*
*GRAPH(SUBHEADER=SEX+POSEXIT) 2
*# %S('F'+SEX+POSEXIT) K 2060:1
*# HP k 2013:1
*
*END DOFOR POSEXIT




*******************************************************************
*                                  [2]                            *
*                                                                 *
*                     Estimate Entry rates for males               *
*                                                                 *
*******************************************************************


COMPUTE SEX = 'M'
*START WITH THOSE THAT REMAIN CONSTANT
SET XM1519 = 0.0;*NET ENTRY CATEGORY
SET XM2024 = 0.0
SET XM2529 = 0.0
SET XM3034 = 0.0


*DOFOR POSENT = 'XXXX'  ;*WHATEVER AGE YOU WANT
*SET %S('X'+SEX+POSENT) = 0.0 ;* THIS ESTABLISHES THIS GROUP AS A +VE NET ENTRY  (ie this is a dummy variable)
*
*
*   COMPUTE K = FIX(%S('EST'+SEX+POSENT)(1))  ;* POINT OF THE STRUCTURAL BREAK
*   SET TREND2 = TREND-K   ;* RESETS T SO THAT IT IS ZERO AT THE POINT WHERE A STRUCTURAL BREAK HAS BEEN DETECTED
*   COMPUTE FLEX = %S('EFLEX'+SEX+POSENT)(2013:1)-K  ;* THE ESTIMATED INFLECTION POINT OF THE LOGISTIC RELATIVE TO THE CORRECTED STARTING VALUE
*   SET HP = %S('NENT'+SEX+POSENT)   ;* NET ENTRY RATE BASED ON SMOOTHED (HODRICK-PRESCOTT) PARTICIPATION RATES
*   COMPUTE POS = %IF(HP(2013:1)-HP(K)>0,1.0,-1.0)
*   COMPUTE LIM = %S('ELIM'+SEX+POSENT)(2013:1);* THIS IS THE MAX OR MIN VALUE OF THE NET EXIT RATE
*   COMPUTE SIGN = %IF(LIM<0,-1.0,1.0)
*   * INITIAL STATES OF RICHARDS PARAMETERS FOR NLLS
*   COMPUTE LAMBDA = -1.0  ;* THIS IS THE LOGISTIC
*   COMPUTE PHI = -3.0 ;* THIS MEANS THAT THE INITIAL VALUE OF PHI IS S.T. THE LONG RUN IS AROUND 95% OF THE LIMIT
*   COMPUTE GROW = SQRT(0.15)
*   *DISP K FLEX POS LIM SIGN LAMBDA PHI GROW
*
*   NONLIN GROW PHI LAMBDA
*   FRML G = -GROW*GROW
*   FRML BETA = (-1.0/LAMBDA)*EXP(-G*FLEX) ;* BASED ON THE RELATIONSHIP BETWEEN BETA AND G AT THE INFLECTION POINT OF A RICHARDS
*   FRML LONG =  HP(2013:1)+(1/(1+EXP(PHI)))*(LIM-HP(2013:1))
*   FRML ALPHA = (HP(2013:1)-LONG)/(((1+BETA*exp(-GROW*GROW*TREND2(2013:1)))^LAMBDA)-1)
*   FRML CON =  LONG-ALPHA
*   FRML F1 HP = CON+ALPHA*(1.0+BETA*EXP(G*TREND2))^LAMBDA
*   nlls(NOPRINT,frml=f1,ITERATIONS=10000,method=SIMPLEX) HP K 2013:1
*   SET %S('F'+SEX+POSENT) = CON+ALPHA*(1.0+BETA*EXP(G*TREND2))^LAMBDA
*
*GRAPH(SUBHEADER=SEX+POSENT) 2
*# %S('F'+SEX+POSENT) K 2060:1
*# HP k 2013:1
*
*END DOFOR POSENT



*******************************************************************
*                                  [1]                            *
*                                                                 *
*                    Estimate EXIT rates for FEMALES              *
*                                                                 *
*******************************************************************

COMPUTE SEX = 'F'
* THIS ESTABLISHES THIS GROUP AS A +VE NET EXIT
SET XF2529 = 1.0
SET XF4549 = 1.0
SET XF5054 = 1.0
SET XF5559 = 1.0
SET XF6064 = 1.0

DOFOR POSEXIT =  '6569'
SET %S('X'+SEX+POSEXIT) = 1.0 ;* THIS ESTABLISHES THIS GROUP AS A +VE NET EXIT

COMPUTE K = FIX(%S('XST'+SEX+POSEXIT)(1))  ;* POINT OF THE STRUCTURAL BREAK
   SET TREND2 = TREND-K   ;* RESETS T SO THAT IT IS ZERO AT THE POINT WHERE A STRUCTURAL BREAK HAS BEEN DETECTED
   COMPUTE FLEX = %S('XFLEX'+SEX+POSEXIT)(2013:1)-K  ;* THE ESTIMATED INFLECTION POINT OF THE LOGISTIC RELATIVE TO THE CORRECTED STARTING VALUE
   SET HP = %S('NEX'+SEX+POSEXIT)   ;* NET EXIT RATE BASED ON SMOOTHED (HODRICK-PRESCOTT) PARTICIPATION RATES
   COMPUTE POS = %IF(HP(2013:1)-HP(K)>0,1.0,-1.0)
   COMPUTE LIM = %S('XLIM'+SEX+POSEXIT)(2013:1);* THIS IS THE MAX OR MIN VALUE OF THE NET EXIT RATE
   COMPUTE SIGN = %IF(LIM<0,-1.0,1.0)
   * INITIAL STATES OF RICHARDS PARAMETERS FOR NLLS
   COMPUTE LAMBDA = -1.0  ;* THIS IS THE LOGISTIC
   COMPUTE PHI = -3.0 ;* THIS MEANS THAT THE INITIAL VALUE OF PHI IS S.T. THE LONG RUN IS AROUND 95% OF THE LIMIT
   COMPUTE GROW = SQRT(0.15)
   *DISP K FLEX POS LIM SIGN LAMBDA PHI GROW

   NONLIN GROW PHI LAMBDA
   FRML G = -GROW*GROW
   FRML BETA = (-1.0/LAMBDA)*EXP(-G*FLEX) ;* BASED ON THE RELATIONSHIP BETWEEN BETA AND G AT THE INFLECTION POINT OF A RICHARDS
   FRML LONG =  HP(2013:1)+(1/(1+EXP(PHI)))*(LIM-HP(2013:1))
   FRML ALPHA = (HP(2013:1)-LONG)/(((1+BETA*exp(-GROW*GROW*TREND2(2013:1)))^LAMBDA)-1)
   FRML CON =  LONG-ALPHA
   FRML F1 HP = CON+ALPHA*(1.0+BETA*EXP(G*TREND2))^LAMBDA
   nlls(NOPRINT,frml=f1,ITERATIONS=10000,method=SIMPLEX) HP K 2013:1
   SET %S('F'+SEX+POSEXIT) = CON+ALPHA*(1.0+BETA*EXP(G*TREND2))^LAMBDA

GRAPH(SUBHEADER=SEX+POSEXIT) 2
# %S('F'+SEX+POSEXIT) K 2060:1
# HP k 2013:1

END DOFOR POSEXIT


*******************************************************************
*                                  [2]                            *
*                                                                 *
*                  Estimate Entry rates for FEMALES               *
*                                                                 *
*******************************************************************

COMPUTE SEX = 'F'
*START WITH THOSE THAT ARE NOT RICHARDS CURVES

*CATEGORISES THESE AS NET ENTRIES
SET XF1519 = 0.0
SET XF2024 = 0.0
SET XF3034 = 0.0
SET XF3539 = 0.0
SET XF4044 = 0.0


*DOFOR POSENT = 'XXXX' ;* SOME AGE RANGE IF RICHARDS CURVE IS USED
*SET %S('X'+SEX+POSENT) = 0.0 ;* THIS ESTABLISHES THIS GROUP AS A +VE NET ENTRY
*
*   COMPUTE K = FIX(%S('EST'+SEX+POSENT)(1))  ;* POINT OF THE STRUCTURAL BREAK
*   SET TREND2 = TREND-K   ;* RESETS T SO THAT IT IS ZERO AT THE POINT WHERE A STRUCTURAL BREAK HAS BEEN DETECTED
*   COMPUTE FLEX = %S('EFLEX'+SEX+POSENT)(2013:1)-K  ;* THE ESTIMATED INFLECTION POINT OF THE LOGISTIC RELATIVE TO THE CORRECTED STARTING VALUE
*   SET HP = %S('NENT'+SEX+POSENT)   ;* NET ENTRY RATE BASED ON SMOOTHED (HODRICK-PRESCOTT) PARTICIPATION RATES
*   COMPUTE POS = %IF(HP(2013:1)-HP(K)>0,1.0,-1.0)
*   COMPUTE LIM = %S('ELIM'+SEX+POSENT)(2013:1);* THIS IS THE MAX OR MIN VALUE OF THE NET EXIT RATE
*   COMPUTE SIGN = %IF(LIM<0,-1.0,1.0)
*   * INITIAL STATES OF RICHARDS PARAMETERS FOR NLLS
*   COMPUTE LAMBDA = -1.0  ;* THIS IS THE LOGISTIC
*   COMPUTE PHI = -3.0 ;* THIS MEANS THAT THE INITIAL VALUE OF PHI IS S.T. THE LONG RUN IS AROUND 95% OF THE LIMIT
*   COMPUTE GROW = SQRT(0.15)
*   *DISP K FLEX POS LIM SIGN LAMBDA PHI GROW
*
*   NONLIN GROW PHI LAMBDA
*   FRML G = -GROW*GROW
*   FRML BETA = (-1.0/LAMBDA)*EXP(-G*FLEX) ;* BASED ON THE RELATIONSHIP BETWEEN BETA AND G AT THE INFLECTION POINT OF A RICHARDS
*   FRML LONG =  HP(2013:1)+(1/(1+EXP(PHI)))*(LIM-HP(2013:1))
*   FRML ALPHA = (HP(2013:1)-LONG)/(((1+BETA*exp(-GROW*GROW*TREND2(2013:1)))^LAMBDA)-1)
*   FRML CON =  LONG-ALPHA
*   FRML F1 HP = CON+ALPHA*(1.0+BETA*EXP(G*TREND2))^LAMBDA
*   nlls(NOPRINT,frml=f1,ITERATIONS=10000,method=SIMPLEX) HP K 2013:1
*   SET %S('F'+SEX+POSENT) = CON+ALPHA*(1.0+BETA*EXP(G*TREND2))^LAMBDA
*
*GRAPH(SUBHEADER=SEX+POSENT) 2
*# %S('F'+SEX+POSENT) K 2060:1
*# HP k 2013:1
*
*END DOFOR POSENT
*
**************END OF RICHARDS CURVE ESTIMATION OF FUTURE EXIT/ENTRY RATES********************************************

*
dofor sex = 'M' 'f'
	DOFOR AGE =  '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569'
   disp 'Exit/entry rate of ' sex age 'is' %s('f'+sex+age)(2060:1)
	End dofor age
end dofor sex





********************************************************************************
*                                                                              *
*                                                                              *
*                                                                              *
*                        COHORT MODEL OF PARTICIPATION RATES                   *
*                                                                              *
*                                                                              *
*******************************************************************************


* UNDERTAKE DYNAMIC COHORT ESTIMATES
IEVAL END_PERIOD = 2060:1
     DOFOR SEX = 'M' 'F'
           COMPUTE MAXP = %IF(SEX=='M',0.99,0.99)
           DO TIME = 2014:1,END_PERIOD,1
              *COMPUTE %S('P'+SEX+'1519')(TIME) = %s('P'+SEX+'1519')(TIME-1)  ;* ONLY USED IF STATIC FORECASTS OF PR1519 USED

              DO AGES = 15,64,5
                  COMPUTE LABEL = %STRING(AGES)+%STRING(AGES+4)
                  COMPUTE LABEL2 = %STRING(AGES+5)+%STRING(AGES+9)
                  COMPUTE %S('P'+SEX+LABEL2)(TIME) = %IF(%S('X'+SEX+LABEL)(TIME)==1.0, $
                  (1.0-%S('F'+SEX+LABEL)(TIME))*%S('P'+SEX+LABEL)(TIME-5), $
                  %S('F'+SEX+LABEL)(TIME)*(MAXP-%S('P'+SEX+LABEL)(TIME-5))+%S('P'+SEX+LABEL)(TIME-5))
              *disp time sex label %s('x'+sex+label)(time) %S('F'+SEX+LABEL)(TIME) %S('P'+SEX+LABEL)(TIME-5)
              END DO AGES

              COMPUTE %S('P'+SEX+'70')(TIME) = %IF(%S('X'+SEX+'6569')(TIME)==1.0, $
              (1.0-%S('F'+SEX+'6569')(TIME))*%S('P'+SEX+'6569')(TIME-5), $
              %S('F'+SEX+'6569')(TIME)*(MAXP-%S('P'+SEX+'6569')(TIME-5))+%S('P'+SEX+'6569')(TIME-5))

           END DO TIME
      END DOFOR SEX





*These are the relevant graphs of
*PRATES


  DOFOR AGE =  '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569' '70'
    set %S('PPM'+AGE) = 100.0*%S('PM'+age)
    set %S('PPF'+AGE) = 100.0* %S('PF'+age)
  END DOFOR AGE

  SET GRID 1979:1 2060:1 = (T==2013:1)
  grparm axislabelling 20 keylabelling 20 subheader 20
  SPGRAPH(HFIELD=3,vfield=4)
  DOFOR AGE =  '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569' '70'
    EXTREMUM(NOPRINT) %S('PPF'+age)
    COMPUTE MINVAL = %MINIMUM*(1.1)
    COMPUTE MAXF = %MAXIMUM
    EXTREMUM(NOPRINT) %S('PPM'+age)
    COMPUTE MAXM = %MAXIMUM
    COMPUTE MAXI = %MAX(MAXF,MAXM)
    graph(SAMESIZE,PICTURE='*.',max=MAXI,NOPATTERNS,VTICKS=4,noticks,grid=grid) 2
    # %S('PPM'+AGE) 1979:1 2030:1  1
    # %S('PPF'+AGE) 1979:1 2030:1  4
    GRTEXT(ALIGN=LEFT,ENTRY=2020:1,Y=MINVAL,SIZE=50) AGE+' years'
  END DOFOR AGE
  SPGRAPH(DONE)



********end of program computing cohort effects****************************************************************
***************************************************************************************************************



*****get data in form for excel to graph some decade cohorts from 1951 to 2011*********************************
/*
dec rectangular cohdatF(12,7)
dofor sex = 'm' 'f'
compute colcount = 0
do periods = 1951,2011,10
  compute colcount = colcount + 1
  compute rowcount = 0
  compute pr = %if(periods-1978+74<=2048:1,%s('P'+sex+'70')(periods-1978+74),%na)   ;* takes account of 70 year olds who are deemed to have a midpoint of 74 yrs
  compute cohdatf(12,colcount) = pr
  dofor midage = 17 22 27 32 37 42 47 52 57 62 67
     compute rowcount = rowcount + 1
     COMPUTE LABEL = %STRING(midage-2)+%STRING(midage+2)
     compute per=periods-1978 ;* this initialises date periods to RATS count form noting 1979:1 is the 1st observation
     compute pr = %if(per+midage<=2048:1,%S('P'+SEX+LABEL)(per+midage),%na)
     compute cohdatf(rowcount,colcount) = pr
  end dofor midage

end do periods
disp 'Results are for gender = ' sex
disp ' cols are birth cohorts 1951 to 2011'
disp ' rows are ages 15-19, 20-24... to 70+'
disp '______________________________________________________________________'
write(format='(f6.5,1x,f6.5,1x,f6.5,1x,f6.5,1x,f6.5,1x,f6.5,1x,f6.5)') cohdatf
disp '______________________________________________________________________'
end dofor sex

*/





***********************************************************************************************************************


* THIS CODE PUTS ALL THE FORECASTS INTO A CONSISTENT NAMED SERIES
* FCPR DENOTES (F) FORECAST (C) COHORT METHOD (PR) PARTICIPATION RATE
DOFOR AGE =  '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569' '70'
DOFOR SEX = 'F' 'M'
SET %S('FCPR'+SEX+AGE) = %IF(t<=2013:1,%s('PR'+SEX+AGE),%s('P'+SEX+AGE))
END DOFOR SEX
END DOFOR AGE



* copy COHORT FORECAST data to an output file
dedit(new) "OUTPUT (B) COHORT METHOD PRATES 1978_79 to 2059_60_PRJ.rat"
DOFOR AGE =  '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569' '70'
			DOFOR SEX = 'F' 'M'
					store %S('FCPR'+SEX+AGE)
					SAVE
			END DOFOR SEX
END DOFOR AGE

* copy COHORT FORECAST data to an output file
open copy "OUTPUT (B) COHORT Labour participation rates forecasts 1978_79 to 2059_60.XLS"
copy(dates,format=xls,org=columns) 1979:1 2060:1 $
FCPRf1519 FCPRm1519  $
FCPRf2024 FCPRm2024  $
FCPRf2529 FCPRm2529  $
FCPRf3034 FCPRm3034  $
FCPRf3539 FCPRm3539  $
FCPRf4044 FCPRm4044  $
FCPRf4549 FCPRm4549  $
FCPRf5054 FCPRm5054  $
FCPRf5559 FCPRm5559  $
FCPRf6064 FCPRm6064  $
FCPRf6569 FCPRm6569  $
FCPRf70 FCPRm70






/* graph part rate forecasts
SET GRID 1979:1 2051:1 = (T==2013:1)
grparm axislabelling 36 keylabelling 36 subheader 36
SPGRAPH(HFIELD=3,vfield=4)
DOFOR AGE =  '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569' '70'
COMPUTE SUBHEADER = 'FEMALES AGED '+age+' years'
graph(subheader=subheader,noPATTERNS,VTICKS=5,ticks,grid=grid) 1
# %S('FCPR'+'F'+age) 1979:1 2051:1  4
END DOFOR AGE
SPGRAPH(DONE)




grparm axislabelling 48 keylabelling 48 subheader 48
SPGRAPH(HFIELD=3,vfield=4)
DOFOR AGE =  '1519' '2024' '2529' '3034' '3539' '4044' '4549' '5054' '5559' '6064' '6569' '70'
COMPUTE SUBHEADER = 'MALES AGED '+age+' years'
graph(subheader=subheader,noPATTERNS,VTICKS=5,ticks,grid=grid) 1
# %S('FCPR'+'m'+age) 1979:1 2051:1  1
END DOFOR AGE
SPGRAPH(DONE)

*/


